==> infima_client-0.59.0-py3-none-any.whl: infima_client/models/pool_characteristics.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.pool_service_get_characteristics_response_200_characteristics_item import (
    PoolService_GetCharacteristicsResponse_200CharacteristicsItem,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="PoolCharacteristics")


@attr.s(auto_attribs=True)
class PoolCharacteristics:
    """  """

    characteristics: Union[
        Unset, List[PoolService_GetCharacteristicsResponse_200CharacteristicsItem]
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        characteristics: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.characteristics, Unset):
            characteristics = []
            for characteristics_item_data in self.characteristics:
                characteristics_item = characteristics_item_data.to_dict()

                characteristics.append(characteristics_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if characteristics is not UNSET:
            field_dict["characteristics"] = characteristics

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        characteristics = []
        _characteristics = d.pop("characteristics", UNSET)
        for characteristics_item_data in _characteristics or []:
            characteristics_item = (
                PoolService_GetCharacteristicsResponse_200CharacteristicsItem.from_dict(
                    characteristics_item_data
                )
            )

            characteristics.append(characteristics_item)

        pool_characteristics = cls(
            characteristics=characteristics,
        )

        pool_characteristics.additional_properties = d
        return pool_characteristics

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> infima_client-0.186.0-py3-none-any.whl: infima_client/models/pool_characteristics.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.characteristic_item import CharacteristicItem
from ..types import UNSET, Unset

T = TypeVar("T", bound="PoolCharacteristics")


@attr.s(auto_attribs=True)
class PoolCharacteristics:
    """  """

    characteristics: Union[Unset, List[CharacteristicItem]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        characteristics: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.characteristics, Unset):
            characteristics = []
            for characteristics_item_data in self.characteristics:
                characteristics_item = characteristics_item_data.to_dict()

                characteristics.append(characteristics_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if characteristics is not UNSET:
            field_dict["characteristics"] = characteristics

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        characteristics = []
        _characteristics = d.pop("characteristics", UNSET)
        for characteristics_item_data in _characteristics or []:
            characteristics_item = CharacteristicItem.from_dict(
                characteristics_item_data
            )

            characteristics.append(characteristics_item)

        pool_characteristics = cls(
            characteristics=characteristics,
        )

        pool_characteristics.additional_properties = d
        return pool_characteristics

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
